package
Version:
v1.1.15
Opens a new window with list of versions in this module.
Published: May 2, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type PostgresFlags struct {
Url string `name:"url" env:"PG_URL" help:"PostgreSQL connection URL"`
Password string `name:"password" env:"PG_PASSWORD" help:"PostgreSQL password"`
}
Connect to the database and return a connection pool, or nil if no URL is set.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.